var NAVTREEINDEX13 =
{
"interfacestarpu__mod_1_1starpu__resume.html":[9,0,2,9],
"interfacestarpu__mod_1_1starpu__shutdown.html":[9,0,2,10],
"interfacestarpu__mod_1_1starpu__task__wait__for__all.html":[9,0,2,11],
"modules.html":[7],
"namespacefstarpu__mod.html#interfacefstarpu__mod_1_1operator_07_8ior_8_08":[10,0,1,1,0],
"namespaces.html":[8,0],
"pages.html":[],
"sc__hypervisor_8h.html":[10,0,3,0,0],
"sc__hypervisor_8h_source.html":[10,0,3,0,0],
"sc__hypervisor__config_8h.html":[10,0,3,0,1],
"sc__hypervisor__config_8h.html#a002798d04e272d4901e06d2909e2d970":[10,0,3,0,1,0,4],
"sc__hypervisor__config_8h.html#a1c071ab4625b8a98fcce0b3ceebccad9":[10,0,3,0,1,0,10],
"sc__hypervisor__config_8h.html#a210d14a5cc6487ffdc76ae35c6a16edb":[10,0,3,0,1,0,7],
"sc__hypervisor__config_8h.html#a3cfede397206c8e6766f5fe8fcfd1fef":[10,0,3,0,1,0,9],
"sc__hypervisor__config_8h.html#a635e8967fa211c34d367c471b847e3c7":[10,0,3,0,1,0,3],
"sc__hypervisor__config_8h.html#a78e03b1cc0e5f7505bb7f0404955d239":[10,0,3,0,1,0,2],
"sc__hypervisor__config_8h.html#a963cb56195d9fa30e905a4d1ba0c4300":[10,0,3,0,1,0,1],
"sc__hypervisor__config_8h.html#a9e0d3d7192aa552436227f5886dc0075":[10,0,3,0,1,0,0],
"sc__hypervisor__config_8h.html#ab2ceb91193882e327559323f3669262b":[10,0,3,0,1,0,6],
"sc__hypervisor__config_8h.html#ac56775b3eafc46d10aaf2162676b72d0":[10,0,3,0,1,0,8],
"sc__hypervisor__config_8h.html#afdb68c657fb202f52938f5268749003d":[10,0,3,0,1,0,5],
"sc__hypervisor__config_8h.html#structsc__hypervisor__policy__config":[10,0,3,0,1,0],
"sc__hypervisor__config_8h_source.html":[10,0,3,0,1],
"sc__hypervisor__lp_8h.html":[10,0,3,0,2],
"sc__hypervisor__lp_8h_source.html":[10,0,3,0,2],
"sc__hypervisor__monitoring_8h.html":[10,0,3,0,3],
"sc__hypervisor__monitoring_8h.html#a063487ad1a8059812b5c4f721bf828f6":[10,0,3,0,3,0,22],
"sc__hypervisor__monitoring_8h.html#a0786fc47b4d17d660cfe66649e4933e7":[10,0,3,0,3,0,9],
"sc__hypervisor__monitoring_8h.html#a0cd92328373b9b5427e6bb48a44d8644":[10,0,3,0,3,0,2],
"sc__hypervisor__monitoring_8h.html#a10b881331a3075f0d1508ee96b0dd50a":[10,0,3,0,3,0,19],
"sc__hypervisor__monitoring_8h.html#a1c6e13064c46813ec41b453acd0174d4":[10,0,3,0,3,0,14],
"sc__hypervisor__monitoring_8h.html#a1e0e2c4e5a03176a09fe4f84a4b5a1ee":[10,0,3,0,3,0,27],
"sc__hypervisor__monitoring_8h.html#a3a8cc8e96001231da38e869e324ce22e":[10,0,3,0,3,0,5],
"sc__hypervisor__monitoring_8h.html#a45b953429183c5a75c83a691d8339e7a":[10,0,3,0,3,0,17],
"sc__hypervisor__monitoring_8h.html#a4aa40a61865a2e10a161b5e8148560bb":[10,0,3,0,3,0,13],
"sc__hypervisor__monitoring_8h.html#a4c01108a62fd573f2a6430381ce7943f":[10,0,3,0,3,0,10],
"sc__hypervisor__monitoring_8h.html#a670c50b3b52c05d3ca95e8717f1b4a6b":[10,0,3,0,3,0,3],
"sc__hypervisor__monitoring_8h.html#a6c2b7e686bd8a6257184688a4e4d52eb":[10,0,3,0,3,0,12],
"sc__hypervisor__monitoring_8h.html#a719b6c515fdb98ad09f549048cc9caa3":[10,0,3,0,3,0,6],
"sc__hypervisor__monitoring_8h.html#a7ed3efcd3b7e2886f5610e5f5920eb99":[10,0,3,0,3,0,1],
"sc__hypervisor__monitoring_8h.html#a8923658556a212b0ed82f2138a4c5850":[10,0,3,0,3,0,7],
"sc__hypervisor__monitoring_8h.html#aa72bfdedf5238e9faaee87f48d72bebe":[10,0,3,0,3,0,20],
"sc__hypervisor__monitoring_8h.html#ab35accf0d5a3a49c1ab43799aad115bb":[10,0,3,0,3,0,0],
"sc__hypervisor__monitoring_8h.html#aba3d21edf846f13f3d41405ab7d99016":[10,0,3,0,3,0,21],
"sc__hypervisor__monitoring_8h.html#abe9c30e847ed5dab431ffb1e753b4829":[10,0,3,0,3,0,15],
"sc__hypervisor__monitoring_8h.html#abf552a3af2c6928c9f4e0dd6e845c7e0":[10,0,3,0,3,0,26],
"sc__hypervisor__monitoring_8h.html#acd3f606a760909b7b7262b2927c537b3":[10,0,3,0,3,0,18],
"sc__hypervisor__monitoring_8h.html#adfb3d97bbdc15b0f9acee62ab4ae6350":[10,0,3,0,3,0,8],
"sc__hypervisor__monitoring_8h.html#adfbc9bbc2fb020e1b0c847f8557e45d6":[10,0,3,0,3,0,24],
"sc__hypervisor__monitoring_8h.html#ae52f8e1b8fdfd299a91890cef366a00a":[10,0,3,0,3,0,23],
"sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d":[10,0,3,0,3,0,28],
"sc__hypervisor__monitoring_8h.html#aee6c9636c4ce6692556e0e87e4d16455":[10,0,3,0,3,0,11],
"sc__hypervisor__monitoring_8h.html#aeffa224cc0e8e84dcc4decb64f2cb54c":[10,0,3,0,3,0,16],
"sc__hypervisor__monitoring_8h.html#aeffdde67d260b4ab8e18a625055ec7c0":[10,0,3,0,3,0,4],
"sc__hypervisor__monitoring_8h.html#afaf7aa117a0cf782337d67ae6ea0f961":[10,0,3,0,3,0,25],
"sc__hypervisor__monitoring_8h.html#structsc__hypervisor__wrapper":[10,0,3,0,3,0],
"sc__hypervisor__monitoring_8h_source.html":[10,0,3,0,3],
"sc__hypervisor__policy_8h.html":[10,0,3,0,4],
"sc__hypervisor__policy_8h_source.html":[10,0,3,0,4],
"starpu_8h.html":[10,0,1,2],
"starpu_8h_source.html":[10,0,1,2],
"starpu__bitmap_8h.html":[10,0,1,3],
"starpu__bitmap_8h.html#structstarpu__bitmap":[10,0,1,3,0],
"starpu__bitmap_8h_source.html":[10,0,1,3],
"starpu__bound_8h.html":[10,0,1,4],
"starpu__bound_8h_source.html":[10,0,1,4],
"starpu__config_8h.html":[10,0,0,0],
"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[10,0,0,0,12],
"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[10,0,0,0,29],
"starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[10,0,0,0,5],
"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[10,0,0,0,28],
"starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[10,0,0,0,4],
"starpu__config_8h_source.html":[10,0,0,0],
"starpu__cublas_8h.html":[10,0,1,5],
"starpu__cublas_8h_source.html":[10,0,1,5],
"starpu__cublas__v2_8h.html":[10,0,1,6],
"starpu__cublas__v2_8h_source.html":[10,0,1,6],
"starpu__cuda_8h.html":[10,0,1,7],
"starpu__cuda_8h_source.html":[10,0,1,7],
"starpu__cusolver_8h.html":[10,0,1,8],
"starpu__cusolver_8h.html#a370a7a73030f807605a9b5e418e29852":[10,0,1,8,3],
"starpu__cusolver_8h.html#a661622267516b78a8c71c60fa8a27c4a":[10,0,1,8,6],
"starpu__cusolver_8h.html#a78866b909f7e937a43d96beb983c2434":[10,0,1,8,5],
"starpu__cusolver_8h.html#a802c617673805d37d62a3213261d121e":[10,0,1,8,4],
"starpu__cusolver_8h.html#aa27808f9256c0b90c2c231b598b16220":[10,0,1,8,0],
"starpu__cusolver_8h.html#adc9d0c6e8728152c6ede31a828c353a6":[10,0,1,8,2],
"starpu__cusolver_8h_source.html":[10,0,1,8],
"starpu__cusparse_8h.html":[10,0,1,9],
"starpu__cusparse_8h_source.html":[10,0,1,9],
"starpu__data_8h.html":[10,0,1,10],
"starpu__data_8h_source.html":[10,0,1,10],
"starpu__data__filters_8h.html":[10,0,1,11],
"starpu__data__filters_8h_source.html":[10,0,1,11],
"starpu__data__interfaces_8h.html":[10,0,1,12],
"starpu__data__interfaces_8h_source.html":[10,0,1,12],
"starpu__deprecated__api_8h.html":[10,0,1,13],
"starpu__deprecated__api_8h_source.html":[10,0,1,13],
"starpu__disk_8h.html":[10,0,1,14],
"starpu__disk_8h_source.html":[10,0,1,14],
"starpu__driver_8h.html":[10,0,1,15],
"starpu__driver_8h_source.html":[10,0,1,15],
"starpu__expert_8h.html":[10,0,1,16],
"starpu__expert_8h_source.html":[10,0,1,16],
"starpu__fxt_8h.html":[10,0,1,17],
"starpu__fxt_8h_source.html":[10,0,1,17],
"starpu__hash_8h.html":[10,0,1,18],
"starpu__hash_8h_source.html":[10,0,1,18],
"starpu__helper_8h.html":[10,0,1,19],
"starpu__helper_8h_source.html":[10,0,1,19],
"starpu__heteroprio_8h.html":[10,0,1,0,0],
"starpu__heteroprio_8h_source.html":[10,0,1,0,0],
"starpu__hip_8h.html":[10,0,1,20],
"starpu__hip_8h_source.html":[10,0,1,20],
"starpu__max__fpga_8h.html":[10,0,1,21],
"starpu__max__fpga_8h_source.html":[10,0,1,21],
"starpu__mod_8f90.html":[10,0,1,22],
"starpu__mpi_8h.html":[10,0,2,0,0],
"starpu__mpi_8h_source.html":[10,0,2,0,0],
"starpu__mpi__ft_8h.html":[10,0,2,0,1],
"starpu__mpi__ft_8h_source.html":[10,0,2,0,1],
"starpu__mpi__lb_8h.html":[10,0,2,0,2],
"starpu__mpi__lb_8h.html#a1692d18d1d2d0df9eae6c148d54167f1":[10,0,2,0,2,1],
"starpu__mpi__lb_8h_source.html":[10,0,2,0,2],
"starpu__opencl_8h.html":[10,0,1,23],
"starpu__opencl_8h_source.html":[10,0,1,23],
"starpu__openmp_8h.html":[10,0,1,24],
"starpu__openmp_8h_source.html":[10,0,1,24],
"starpu__parallel__worker_8h.html":[10,0,1,25],
"starpu__parallel__worker_8h_source.html":[10,0,1,25],
"starpu__perf__monitoring_8h.html":[10,0,1,26],
"starpu__perf__monitoring_8h_source.html":[10,0,1,26],
"starpu__perf__steering_8h.html":[10,0,1,27],
"starpu__perf__steering_8h_source.html":[10,0,1,27],
"starpu__perfmodel_8h.html":[10,0,1,28],
"starpu__perfmodel_8h_source.html":[10,0,1,28],
"starpu__profiling_8h.html":[10,0,1,29],
"starpu__profiling_8h_source.html":[10,0,1,29],
"starpu__profiling__tool_8h.html":[10,0,1,30],
"starpu__profiling__tool_8h_source.html":[10,0,1,30],
"starpu__rand_8h.html":[10,0,1,31],
"starpu__rand_8h_source.html":[10,0,1,31],
"starpu__sched__component_8h.html":[10,0,1,32],
"starpu__sched__component_8h_source.html":[10,0,1,32],
"starpu__sched__ctx_8h.html":[10,0,1,33],
"starpu__sched__ctx_8h_source.html":[10,0,1,33],
"starpu__sched__ctx__hypervisor_8h.html":[10,0,1,34],
"starpu__sched__ctx__hypervisor_8h.html#a62867177a48ccd40ac944602630cd8f0":[10,0,1,34,2],
"starpu__sched__ctx__hypervisor_8h.html#a95283c927a7787e2859cb4a42c93bf19":[10,0,1,34,4],
"starpu__sched__ctx__hypervisor_8h.html#ae7de365db4b774cdea340f7548e93c9d":[10,0,1,34,3],
"starpu__sched__ctx__hypervisor_8h.html#aee24cd7da1cde089e038b93f52d1bf1d":[10,0,1,34,1],
"starpu__sched__ctx__hypervisor_8h_source.html":[10,0,1,34],
"starpu__scheduler_8h.html":[10,0,1,35],
"starpu__scheduler_8h_source.html":[10,0,1,35],
"starpu__scheduler__toolbox_8h.html":[10,0,1,0,1],
"starpu__scheduler__toolbox_8h_source.html":[10,0,1,0,1],
"starpu__simgrid__wrap_8h.html":[10,0,1,36],
"starpu__simgrid__wrap_8h_source.html":[10,0,1,36],
"starpu__sink_8h.html":[10,0,1,37],
"starpu__sink_8h_source.html":[10,0,1,37],
"starpu__stdlib_8h.html":[10,0,1,38],
"starpu__stdlib_8h_source.html":[10,0,1,38],
"starpu__task_8h.html":[10,0,1,39],
"starpu__task_8h.html#a01d7ce55a1643b886608e93451bcd460":[10,0,1,39,16],
"starpu__task_8h_source.html":[10,0,1,39],
"starpu__task__bundle_8h.html":[10,0,1,40],
"starpu__task__bundle_8h_source.html":[10,0,1,40],
"starpu__task__dep_8h.html":[10,0,1,41],
"starpu__task__dep_8h_source.html":[10,0,1,41],
"starpu__task__list_8h.html":[10,0,1,42],
"starpu__task__list_8h_source.html":[10,0,1,42],
"starpu__task__util_8h.html":[10,0,1,43],
"starpu__task__util_8h_source.html":[10,0,1,43],
"starpu__thread_8h.html":[10,0,1,44],
"starpu__thread_8h.html#structstarpu__pthread__attr__t":[10,0,1,44,0],
"starpu__thread_8h.html#structstarpu__pthread__barrier__t":[10,0,1,44,1],
"starpu__thread_8h.html#structstarpu__pthread__queue__t":[10,0,1,44,4],
"starpu__thread_8h.html#structstarpu__pthread__spinlock__t":[10,0,1,44,2],
"starpu__thread_8h.html#structstarpu__pthread__wait__t":[10,0,1,44,3],
"starpu__thread_8h_source.html":[10,0,1,44],
"starpu__thread__util_8h.html":[10,0,1,45],
"starpu__thread__util_8h_source.html":[10,0,1,45],
"starpu__tree_8h.html":[10,0,1,46],
"starpu__tree_8h_source.html":[10,0,1,46],
"starpu__util_8h.html":[10,0,1,47],
"starpu__util_8h_source.html":[10,0,1,47],
"starpu__worker_8h.html":[10,0,1,48],
"starpu__worker_8h_source.html":[10,0,1,48],
"starpufft_8h.html":[10,0,4,0,0],
"starpufft_8h_source.html":[10,0,4,0,0],
"starpurm_8h.html":[10,0,5,0,0],
"starpurm_8h_source.html":[10,0,5,0,0],
"structstarpu__mpi__lb__conf.html":[9,0,28],
"structstarpu__sched__ctx__performance__counters.html":[9,0,64],
"structstarpu__sched__ctx__performance__counters.html#a00d4a30b5df9055dd8863e11f92e95d9":[9,0,64,1],
"structstarpu__sched__ctx__performance__counters.html#a224f60afb4fe34d888364a609fcd8a54":[9,0,64,3],
"structstarpu__sched__ctx__performance__counters.html#a2a0a4cb4bc0cc262904f4c14b831648c":[9,0,64,2],
"structstarpu__sched__ctx__performance__counters.html#ac8f1d93575941d46827c066b169c60af":[9,0,64,5],
"structstarpu__sched__ctx__performance__counters.html#adb06b01cfff042b9355ff7a1841776e2":[9,0,64,0],
"structstarpu__sched__ctx__performance__counters.html#ae9905661cc65e48baed16c249576515d":[9,0,64,4]
};
